Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1065)

Unified Diff: net/proxy/proxy_config_service_mac.h

Issue 2957433002: Use SequencedTaskRunner rather than SingledThreadedTaskRunner for passing io_task_runner (Closed)
Patch Set: undo change to glib_task_runner (keep it SingleThreadBlaBla) Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/proxy/proxy_config_service_linux.cc ('k') | net/proxy/proxy_config_service_mac.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/proxy/proxy_config_service_mac.h
diff --git a/net/proxy/proxy_config_service_mac.h b/net/proxy/proxy_config_service_mac.h
index 1ee40d903f1c3019144848733cf0108adb556fff..d9d08c70d66a08ff8061673acf5b7af6cb0de4ea 100644
--- a/net/proxy/proxy_config_service_mac.h
+++ b/net/proxy/proxy_config_service_mac.h
@@ -16,7 +16,7 @@
#include "net/proxy/proxy_config_service.h"
namespace base {
-class SingleThreadTaskRunner;
+class SequencedTaskRunner;
} // namespace base
namespace net {
@@ -24,10 +24,10 @@ namespace net {
class ProxyConfigServiceMac : public ProxyConfigService {
public:
// Constructs a ProxyConfigService that watches the Mac OS system settings.
// This instance is expected to be operated and deleted on the same thread
// (however it may be constructed from a different thread).
explicit ProxyConfigServiceMac(
- const scoped_refptr<base::SingleThreadTaskRunner>& io_thread_task_runner);
+ const scoped_refptr<base::SequencedTaskRunner>& io_thread_task_runner);
~ProxyConfigServiceMac() override;
public:
@@ -74,8 +74,8 @@ class ProxyConfigServiceMac : public ProxyConfigService {
scoped_refptr<Helper> helper_;
- // The thread that we expect to be operated on.
- const scoped_refptr<base::SingleThreadTaskRunner> io_thread_task_runner_;
+ // The task runner that |this| will be operated on.
+ const scoped_refptr<base::SequencedTaskRunner> io_thread_task_runner_;
DISALLOW_COPY_AND_ASSIGN(ProxyConfigServiceMac);
};
« no previous file with comments | « net/proxy/proxy_config_service_linux.cc ('k') | net/proxy/proxy_config_service_mac.cc » ('j') | no next file with comments »
@@ -24,10 +24,10 @@ namespace net {
public:
// Constructs a ProxyConfigService that watches the Mac OS system settings.
- // This instance is expected to be operated and deleted on the same thread
- // (however it may be constructed from a different thread).
+ // This instance is expected to be operated and deleted on the
+ // same sequenced task runner (however it may be constructed elsewhere).
explicit ProxyConfigServiceMac(

Powered by Google App Engine
This is Rietveld 408576698